@@ -25,7 +25,7 @@ __all__ = (
     "_rearrange_params",
     "rearrange_params",
     "multiparams",
-)
+    "add_api_name")
 
 
 def default_headers() -> Dict[str, str]:
@@ -35,6 +35,7 @@ def default_headers() -> Dict[str, str]:
         "accept-encoding": ", ".join(("gzip", "deflate")),
         "cache-control": "no-cache",
         "pragma": "no-cache",
+        # "content-encoding": "utf-8",
     }
 
 
@@ -149,3 +150,18 @@ def multiparams(func):
             params = _rearrange_params(args, kwargs)
             return [func(*a, **kw) for a, kw in params]
     return update_wrapper(wrapper, func)
+
+
+def add_api_name(default_api):
+    def decorator(func):
+        if iscorofunc(func):
+            async def wrapper(self, *args, api: str = default_api, **kwargs):
+                self._current_api = api
+                return await func(self, *args, **kwargs)
+        else:
+            def wrapper(self, *args, api: str = default_api, **kwargs):
+                self._current_api = api
+                return func(self, *args, **kwargs)
+
+        return update_wrapper(wrapper, func)
+    return decorator
