@@ -15,7 +15,7 @@ from .api_toolkit import (
 from .base_classes import AsyncInitObject, AsyncWith, SyncWith
 from .cache_utils import somecachedmethod, iscorofunc
 from .exceptions import WITH_CODE, UnexpectedResponseCode
-from .typedefs import URLS, L, R
+from .typedefs import URLS, JSONSEQ, JSONT, NUMBER
 
 from typing import (
     Any,
@@ -35,14 +35,14 @@ from typing import (
 )
 
 import orjson
+# from unicodedata import normalize  # "NFKC" or "NFKD"
 
 __all__ = (
     "AsyncSession",
-    "SyncSession",
-)
+    "SyncSession")
 
 
-# XXX: in both functions I need to find a suitable cache_limit
+# FIXME: in both functions I need to find a suitable cache_limit
 # 1024 is a relatively random choice and
 # has nothing to do with the desired behavior
 
@@ -220,10 +220,10 @@ def headers_handler(self, headers):
 
 class AsyncSession(AsyncInitObject, AsyncWith):
     async def __init__(self, trust_env: bool = True,
-                       cache_ttl: Union[int, float] = 60,
+                       cache_ttl: NUMBER = 60,
                        cache_limit: int = 1024,
                        use_cache: bool = True,
-                       timeout: Union[int, float] = 30,
+                       timeout: NUMBER = 30,
                        repeat_failed: int = 3) -> None:
         headers = default_headers()
         loop = asyncio.get_event_loop()
@@ -288,14 +288,14 @@ class AsyncSession(AsyncInitObject, AsyncWith):
     _gets = retry_to_get_data(mix_all_gets(True)(_simple_get))
 
     async def get(self, url: str, from_json: bool = True,
-                  headers: Dict[str, str] = {}) -> R:
+                  headers: Dict[str, str] = {}) -> JSONT:
         return (await self._get(
             url, from_json=from_json,
             headers=headers_handler(self, headers)))[0]
 
     async def gets(
             self, urls: URLS, from_json: bool = True,
-            headers: Union[List[Dict[str, str]], Dict[str, str]] = {}) -> L:
+            headers: Union[List[Dict[str, str]], Dict[str, str]] = {}) -> JSONSEQ:
         return await self._gets(
             urls, from_json=from_json,
             headers=headers_handler(self, headers))
@@ -303,9 +303,9 @@ class AsyncSession(AsyncInitObject, AsyncWith):
 
 class SyncSession(SyncWith):
     def __init__(self, trust_env: bool = True,
-                 cache_ttl: Union[int, float] = 60,
+                 cache_ttl: NUMBER = 60,
                  cache_limit: int = 1024, use_cache: bool = True,
-                 timeout: Union[int, float] = 30,
+                 timeout: NUMBER = 30,
                  repeat_failed: int = 3) -> None:
         self._closed = False
 
@@ -365,11 +365,11 @@ class SyncSession(SyncWith):
     _gets = retry_to_get_data(mix_all_gets(True)(_simple_get))
 
     def get(self, url: str, from_json: bool = True,
-            headers: Dict[str, str] = {}) -> R:
+            headers: Dict[str, str] = {}) -> JSONT:
         return self._get(url, from_json=from_json,
                          headers=headers_handler(self, headers))[0]
 
     def gets(self, urls: URLS, from_json: bool = True,
-             headers: Union[List[Dict[str, str]], Dict[str, str]] = {}) -> L:
+             headers: Union[List[Dict[str, str]], Dict[str, str]] = {}) -> JSONSEQ:
         return self._gets(urls, from_json=from_json,
                           headers=headers_handler(self, headers))
